@@ -381,7 +381,7 @@ def download_subcommand(
 
     Download all books in EPUB format whose title includes 'python':
 
-    `$ springer download books --name python --file-format epub`
+    `$ springer download books --name python --format epub`
 
     Download all books into directories grouped by package:
 
@@ -389,7 +389,7 @@ def download_subcommand(
 
     Download all books in a specific package in EPUB format:
 
-    `$ springer download package --name 'Computer Science' --file-format epub`
+    `$ springer download package --name 'Computer Science' --format epub`
 
     Download all books in packages whose name includes `Science`:
 
@@ -397,7 +397,7 @@ def download_subcommand(
 
     Download all books in all catalogs [en-all, de-all, de-med] in EPUB format:
 
-    `$ springer download catalogs --file-format epub`
+    `$ springer download catalogs --format epub`
 
     The `catalogs` download subcommand will create a set of directories by language
     and topic for each catalog and save downloaded files into the appropriate
@@ -469,3 +469,10 @@ def download_subcommand(
         typer.secho("Permission error for: ", nl=False)
         typer.secho(str(error.filename), fg="red")
         raise typer.Exit(-1) from None
+
+
+@cli.command("version")
+def version_subcommand(ctx: typer.Context):
+    from .__version__ import __version__
+
+    typer.secho(f"{__version__}", fg="green")
